@@ -1,6 +1,6 @@
 /*
   Copyright (C) 2009-2018  Brazil
-  Copyright (C) 2019-2024  Sutou Kouhei <kou@clear-code.com>
+  Copyright (C) 2019-2025  Sutou Kouhei <kou@clear-code.com>
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -438,7 +438,7 @@ grn_ctx_impl_init(grn_ctx *ctx)
     ctx->impl->match_escalation_threshold =
       grn_get_default_match_escalation_threshold();
   }
-  ctx->impl->force_match_escalation = GRN_FALSE;
+  ctx->impl->force_match_escalation = false;
 
   ctx->impl->finalizer = NULL;
 
@@ -453,7 +453,6 @@ grn_ctx_impl_init(grn_ctx *ctx)
 #endif
   ctx->impl->output.arrow_stream_writer = NULL;
   grn_timeval_now(ctx, &ctx->impl->tv);
-  ctx->impl->edge = NULL;
 #ifdef GRN_WITH_APACHE_ARROW
   ctx->impl->arrow_stream_loader = NULL;
 #endif
@@ -1405,18 +1404,18 @@ grn_ctx_set_match_escalation_threshold(grn_ctx *ctx, int64_t threshold)
   return GRN_SUCCESS;
 }
 
-grn_bool
+bool
 grn_ctx_get_force_match_escalation(grn_ctx *ctx)
 {
   if (ctx->impl) {
     return ctx->impl->force_match_escalation;
   } else {
-    return GRN_FALSE;
+    return false;
   }
 }
 
 grn_rc
-grn_ctx_set_force_match_escalation(grn_ctx *ctx, grn_bool force)
+grn_ctx_set_force_match_escalation(grn_ctx *ctx, bool force)
 {
   if (ctx->impl) {
     ctx->impl->force_match_escalation = force;
